@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::ResultSet::Upload;
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 # ABSTRACT: Query the CPAN uploads data
 
 #pod =head1 SYNOPSIS
@@ -19,18 +19,8 @@ our $VERSION = '0.005';
 #pod
 #pod =head1 SEE ALSO
 #pod
-#pod =over
-#pod
-#pod =item L<CPAN::Testers::Schema::Result::Upload>
-#pod
-#pod =item L<DBIx::Class::ResultSet>
-#pod
-#pod =item L<CPAN::Testers::Schema>
-#pod
-#pod =item L<http://github.com/cpan-testers/cpantesters-project>
-#pod
-#pod For an overview of how the CPANTesters project works, and for information about
-#pod project goals and to get involved.
+#pod L<CPAN::Testers::Schema::Result::Upload>, L<DBIx::Class::ResultSet>,
+#pod L<CPAN::Testers::Schema>
 #pod
 #pod =cut
 
@@ -89,7 +79,7 @@ CPAN::Testers::Schema::ResultSet::Upload - Query the CPAN uploads data
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -130,18 +120,8 @@ ISO8601 date.
 
 =head1 SEE ALSO
 
-=over
-
-=item L<CPAN::Testers::Schema::Result::Upload>
-
-=item L<DBIx::Class::ResultSet>
-
-=item L<CPAN::Testers::Schema>
-
-=item L<http://github.com/cpan-testers/cpantesters-project>
-
-For an overview of how the CPANTesters project works, and for information about
-project goals and to get involved.
+L<CPAN::Testers::Schema::Result::Upload>, L<DBIx::Class::ResultSet>,
+L<CPAN::Testers::Schema>
 
 =head1 AUTHORS
 
